@@ -1,10 +1,22 @@
 /*
  * gnect prefs.h
  *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public
+ * License along with this program; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA. 
  */
 
-
-
 #ifndef _GNECT_PREFS_H_
 #define _GNECT_PREFS_H_
 
@@ -23,9 +35,11 @@
 #define SOUND_MODE_BEEP         1
 #define SOUND_MODE_PLAY         2
 
-#define KEY_LEFT                0
-#define KEY_RIGHT               1
-#define KEY_DROP                2
+typedef enum {
+        KEY_LEFT = 0,
+        KEY_RIGHT,
+        KEY_DROP
+} KeyID;
 
 
 
@@ -44,16 +58,15 @@ struct _Prefs {
 	gboolean   do_animate;
 	gboolean   do_toolbar;
 	gboolean   do_sound;
-	gboolean   do_verify;
 	gboolean   changed;
 };
 
 
-void prefs_init(gint argc, gchar **argv);
-void prefs_free(void);
-void prefs_get(void);
-void prefs_save(void);
-void prefs_dialog(void);
+void prefs_init (gint argc, gchar **argv);
+void prefs_free (void);
+void prefs_get (void);
+void prefs_save (void);
+void prefs_dialog (void);
 
 
 #endif
